/******************************************************************************
 *            main.c                                                          *
 *                                                                            *
 *  Copyright  2006  gerald.dumas                                             *
 *  linechec@laposte.net                                                      *
 ******************************************************************************
 *                                                                            *
 *  This program is free software; you can redistribute it and/or modify      *
 *  it under the terms of the GNU General Public License as published by      *
 *  the Free Software Foundation; either version 2 of the License, or         *
 *  any later version.                                                        *
 *                                                                            *
 *  This program is distributed in the hope that it will be useful,           *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 *  GNU General Public License for more details.                              *
 *                                                                            *
 *  You should have received a copy of the GNU General Public License         *
 *  along with this program; if not, write to the Free Software               *
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.*
 ******************************************************************************/

/* création de la fenêtre principale du jeu */


#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif
#include "global.h"
#include <stdlib.h>

#include "g_fenetre_principale.h"


/* Install un 'handler' sur une mauvaise allocation memoire
*  --
*  entree : int sig :
*  retour : -
*/
void segfault_handler(int sig)
{
	g_print ("\n=========================================================\n");
	g_print ("=  Segmentation fault\n");
	g_print (_("=  Adressage memoire invalide\n"));
	g_print ("=-------------------------------------------------------=\n");
	g_print ("=      You've probably found a bug in LINECHEC\n");
	g_print (_("=      Vous avez probablement trouve un bug dans LINECHEC\n"));
	g_print ("=========================================================\n\n");
		
	exit (EXIT_FAILURE);
}

int main(int argc,char **argv)
{
	GtkWidget *fenetre_principale=NULL;
	GtkWidget *Zone_dessin;
	GtkWidget *bouton_debut;
	GtkWidget *bouton_recul;
	GtkWidget *splash_window=NULL;
	GtkWidget *barre_outils;

	PRINT_FUNC_LF();
	g_print ("\n");
	g_print ("***************************\n");
	g_print ("%s %s\n", PACKAGE, VERSION);
	g_print ("***************************\n");
	g_print ("%s %s compiled at %s %s\n", PACKAGE_NAME, VERSION, __DATE__, __TIME__);
	g_print ("Compiler: gcc %s\n", __VERSION__);
	g_print ("***************************\n");
	g_print ("Gtk version  = %d.%d.%d\n", GTK_MAJOR_VERSION, GTK_MICRO_VERSION, GTK_MINOR_VERSION);
	g_print ("Glib version = %d.%d.%d\n", GLIB_MAJOR_VERSION, GLIB_MICRO_VERSION, GLIB_MINOR_VERSION);
	g_print ("***************************\n\n");
	
	// IF Segmentation fault
	signal (SIGSEGV, segfault_handler);
	
	// Initialisation des bibliothèques GTK
	gtk_init(&argc, &argv);

	// Initialisation du fichier de configuration
	configuration_soft(argc, argv);

	// Initialisation du moteur du jeu d'échec
	liste_coups_jouables=echec_init(liste_coups_jouables);

	// Initialisation des différentes variables graphiques nécessaires et
	// construction de la fenetre principale.
	splash_window=g_echecs_init(splash_window);

	// Création d'une fenetre principale
	fenetre_principale=nouvelle_fenetre_principale(fenetre_principale);
	widget_list=gtk_data_list_add_by_name(widget_list, fenetre_principale,
																													"fenetre_principale");

	// affichage complet de tous les widgets
	gtk_widget_show_all(fenetre_principale);
	Zone_dessin=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "Zone dessin"));
	bouton_debut=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "bouton debut"));
	bouton_recul=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "bouton recul"));
	barre_outils=(GtkWidget*)
								(gtk_data_list_get_by_name(widget_list, "barre outils"));

	// Si une partie doit être chargée au démarrage
	if (incorporation_pgn_dans_jeu (filename) == 0)
	{
		// Autorisation de navigation
		gtk_widget_set_sensitive (bouton_debut, TRUE);
		gtk_widget_set_sensitive (bouton_recul, TRUE);
		// Initialisation du tablau des pièces prises
		g_affichage_pieces_prises ();
		// On redessine l'échiquier
		gtk_widget_queue_draw (Zone_dessin);
		gtk_widget_set_sensitive (GTK_WIDGET(gtk_toolbar_get_nth_item(GTK_TOOLBAR (barre_outils), 6)), TRUE);
	}

	// Suppression du splash screen
	gtk_widget_destroy(splash_window);

	// boucle principale
	gtk_main();

	return 0;
}
